@@ -88,9 +88,12 @@ def groundwork_paginator(context):
     ListView and Paginator classes.
     '''
     if not context['is_paginated']:
-        return ''
+        return {
+            'is_paginated': False,
+        }
 
     return {
+        'is_paginated': True,
         'page_obj': context['page_obj'],
         'paginator': context['paginator'],
     }
\ No newline at end of file
